<?php
/*
Plugin Name: Product Price by Formula for WooCommerce
Plugin URI: https://wpfactory.com/item/product-price-by-formula-for-woocommerce/
Description: Set formula for automatic WooCommerce product price calculation.
Version: 2.1.2
Author: Algoritmika Ltd
Author URI: http://algoritmika.com
Text Domain: product-price-by-formula-for-woocommerce
Domain Path: /langs
Copyright:  2019 Algoritmika Ltd.
WC tested up to: 3.5
License: GNU General Public License v3.0
License URI: http://www.gnu.org/licenses/gpl-3.0.html
*/

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

// Check if WooCommerce is active
$plugin = 'woocommerce/woocommerce.php';
if (
	! in_array( $plugin, apply_filters( 'active_plugins', get_option( 'active_plugins', array() ) ) ) &&
	! ( is_multisite() && array_key_exists( $plugin, get_site_option( 'active_sitewide_plugins', array() ) ) )
) {
	return;
}

if ( 'product-price-by-formula-for-woocommerce.php' === basename( __FILE__ ) ) {
	// Check if Pro is active, if so then return
	$plugin = 'product-price-by-formula-for-woocommerce-pro/product-price-by-formula-for-woocommerce-pro.php';
	if (
		in_array( $plugin, apply_filters( 'active_plugins', get_option( 'active_plugins', array() ) ) ) ||
		( is_multisite() && array_key_exists( $plugin, get_site_option( 'active_sitewide_plugins', array() ) ) )
	) {
		return;
	}
}

if ( ! class_exists( 'Alg_WC_PPBF' ) ) :

/**
 * Main Alg_WC_PPBF Class
 *
 * @class   Alg_WC_PPBF
 * @version 2.1.2
 * @since   1.0.0
 */
final class Alg_WC_PPBF {

	/**
	 * Plugin version.
	 *
	 * @var   string
	 * @since 1.0.0
	 */
	public $version = '2.1.2';

	/**
	 * @var   Alg_WC_PPBF The single instance of the class
	 * @since 1.0.0
	 */
	protected static $_instance = null;

	/**
	 * Main Alg_WC_PPBF Instance
	 *
	 * Ensures only one instance of Alg_WC_PPBF is loaded or can be loaded.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @static
	 * @return  Alg_WC_PPBF - Main instance
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * Alg_WC_PPBF Constructor.
	 *
	 * @version 2.0.0
	 * @since   1.0.0
	 * @access  public
	 */
	function __construct() {

		// Set up localisation
		load_plugin_textdomain( 'product-price-by-formula-for-woocommerce', false, dirname( plugin_basename( __FILE__ ) ) . '/langs/' );

		// Include required files
		$this->includes();

		// Admin
		if ( is_admin() ) {
			add_filter( 'woocommerce_get_settings_pages', array( $this, 'add_woocommerce_settings_tab' ) );
			add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'action_links' ) );
			// Settings
			require_once( 'includes/settings/class-alg-wc-ppbf-metaboxes.php' );
			require_once( 'includes/settings/class-alg-wc-ppbf-settings-section.php' );
			$this->settings = array();
			$this->settings['general']           = require_once( 'includes/settings/class-alg-wc-ppbf-settings-general.php' );
			$this->settings['default_formula']   = require_once( 'includes/settings/class-alg-wc-ppbf-settings-default-formula.php' );
			// Version updated
			if ( get_option( 'alg_wc_ppbf_version', '' ) !== $this->version ) {
				add_action( 'admin_init', array( $this, 'verison_updated' ) );
			}
		}
	}

	/**
	 * Show action links on the plugin screen.
	 *
	 * @version 1.1.0
	 * @since   1.0.0
	 * @param   mixed $links
	 * @return  array
	 */
	function action_links( $links ) {
		$custom_links = array();
		$custom_links[] = '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=alg_wc_ppbf' ) . '">' . __( 'Settings', 'woocommerce' ) . '</a>';
		if ( 'product-price-by-formula-for-woocommerce.php' === basename( __FILE__ ) ) {
			$custom_links[] = '<a href="https://wpfactory.com/item/product-price-by-formula-for-woocommerce/">' .
				__( 'Unlock All', 'product-price-by-formula-for-woocommerce' ) . '</a>';
		}
		return array_merge( $custom_links, $links );
	}

	/**
	 * Include required core files used in admin and on the frontend.
	 *
	 * @version 2.0.0
	 * @since   1.0.0
	 */
	function includes() {
		// Lib
		require_once( 'includes/lib/PHPMathParser/Math.php' );
		// Core
		$this->core = require_once( 'includes/class-alg-wc-ppbf-core.php' );
	}

	/**
	 * verison_updated.
	 *
	 * @version 1.1.0
	 * @since   1.1.0
	 */
	function verison_updated() {
		foreach ( $this->settings as $section ) {
			foreach ( $section->get_settings() as $value ) {
				if ( isset( $value['default'] ) && isset( $value['id'] ) ) {
					$autoload = isset( $value['autoload'] ) ? ( bool ) $value['autoload'] : true;
					add_option( $value['id'], $value['default'], '', ( $autoload ? 'yes' : 'no' ) );
				}
			}
		}
		update_option( 'alg_wc_ppbf_version', $this->version );
	}

	/**
	 * Add Product Price by Formula settings tab to WooCommerce settings.
	 *
	 * @version 2.0.0
	 * @since   1.0.0
	 */
	function add_woocommerce_settings_tab( $settings ) {
		$settings[] = require_once( 'includes/settings/class-alg-wc-settings-ppbf.php' );
		return $settings;
	}

	/**
	 * Get the plugin url.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @return  string
	 */
	function plugin_url() {
		return untrailingslashit( plugin_dir_url( __FILE__ ) );
	}

	/**
	 * Get the plugin path.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @return  string
	 */
	function plugin_path() {
		return untrailingslashit( plugin_dir_path( __FILE__ ) );
	}

}

endif;

if ( ! function_exists( 'alg_wc_ppbf' ) ) {
	/**
	 * Returns the main instance of Alg_WC_PPBF to prevent the need to use globals.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 * @return  Alg_WC_PPBF
	 */
	function alg_wc_ppbf() {
		return Alg_WC_PPBF::instance();
	}
}

alg_wc_ppbf();
